# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'UserProfile'
        db.create_table('poem_userprofile', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('user', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['auth.User'], unique=True)),
            ('subject', self.gf('django.db.models.fields.CharField')(max_length=255, unique=True, null=True, blank=True)),
        ))
        db.send_create_signal('poem', ['UserProfile'])

        # Adding model 'MetricInstance'
        db.create_table('poem_metricinstance', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('fqan', self.gf('django.db.models.fields.CharField')(max_length=128, null=True, blank=True)),
            ('metric', self.gf('django.db.models.fields.CharField')(max_length=128, null=True)),
            ('atp_service_type_flavour', self.gf('django.db.models.fields.CharField')(max_length=128, null=True)),
        ))
        db.send_create_signal('poem', ['MetricInstance'])

        # Adding model 'GroupReference'
        db.create_table('poem_groupreference', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('atp_grouptype', self.gf('django.db.models.fields.CharField')(max_length=100, null=True, blank=True)),
            ('atp_groupname', self.gf('django.db.models.fields.CharField')(max_length=100, null=True, blank=True)),
            ('is_deleted', self.gf('django.db.models.fields.CharField')(default='N', max_length=1, null=True)),
            ('description', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
        ))
        db.send_create_signal('poem', ['GroupReference'])

        # Adding unique constraint on 'GroupReference', fields ['atp_grouptype', 'atp_groupname']
        db.create_unique('poem_groupreference', ['atp_grouptype', 'atp_groupname'])

        # Adding model 'Extension'
        db.create_table('poem_extension', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100, null=True, blank=True)),
        ))
        db.send_create_signal('poem', ['Extension'])

        # Adding model 'AvailabilityExpression'
        db.create_table('poem_availabilityexpression', (
            ('extension_ptr', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['poem.Extension'], unique=True, primary_key=True)),
            ('expr', self.gf('django.db.models.fields.CharField')(max_length=255, null=True)),
            ('expr_type', self.gf('django.db.models.fields.CharField')(max_length=255, null=True)),
        ))
        db.send_create_signal('poem', ['AvailabilityExpression'])

        # Adding model 'Profile'
        db.create_table('poem_profile', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=128, null=True)),
            ('version', self.gf('django.db.models.fields.CharField')(default='1.0', max_length=10, null=True)),
            ('valid', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('atp_vo', self.gf('django.db.models.fields.CharField')(max_length=128, null=True)),
            ('valid_from', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('valid_to', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('owner', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('description', self.gf('django.db.models.fields.CharField')(max_length=1024, null=True, blank=True)),
        ))
        db.send_create_signal('poem', ['Profile'])

        # Adding unique constraint on 'Profile', fields ['name', 'version']
        db.create_unique('poem_profile', ['name', 'version'])

        # Adding M2M table for field metric_instances on 'Profile'
        db.create_table('poem_profile_metric_instances', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('profile', models.ForeignKey(orm['poem.profile'], null=False)),
            ('metricinstance', models.ForeignKey(orm['poem.metricinstance'], null=False))
        ))
        db.create_unique('poem_profile_metric_instances', ['profile_id', 'metricinstance_id'])

        # Adding M2M table for field groups on 'Profile'
        db.create_table('poem_profile_groups', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('profile', models.ForeignKey(orm['poem.profile'], null=False)),
            ('groupreference', models.ForeignKey(orm['poem.groupreference'], null=False))
        ))
        db.create_unique('poem_profile_groups', ['profile_id', 'groupreference_id'])

        # Adding M2M table for field extensions on 'Profile'
        db.create_table('poem_profile_extensions', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('profile', models.ForeignKey(orm['poem.profile'], null=False)),
            ('extension', models.ForeignKey(orm['poem.extension'], null=False))
        ))
        db.create_unique('poem_profile_extensions', ['profile_id', 'extension_id'])


    def backwards(self, orm):
        
        # Removing unique constraint on 'Profile', fields ['name', 'version']
        db.delete_unique('poem_profile', ['name', 'version'])

        # Removing unique constraint on 'GroupReference', fields ['atp_grouptype', 'atp_groupname']
        db.delete_unique('poem_groupreference', ['atp_grouptype', 'atp_groupname'])

        # Deleting model 'UserProfile'
        db.delete_table('poem_userprofile')

        # Deleting model 'MetricInstance'
        db.delete_table('poem_metricinstance')

        # Deleting model 'GroupReference'
        db.delete_table('poem_groupreference')

        # Deleting model 'Extension'
        db.delete_table('poem_extension')

        # Deleting model 'AvailabilityExpression'
        db.delete_table('poem_availabilityexpression')

        # Deleting model 'Profile'
        db.delete_table('poem_profile')

        # Removing M2M table for field metric_instances on 'Profile'
        db.delete_table('poem_profile_metric_instances')

        # Removing M2M table for field groups on 'Profile'
        db.delete_table('poem_profile_groups')

        # Removing M2M table for field extensions on 'Profile'
        db.delete_table('poem_profile_extensions')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '80', 'unique': 'True', 'null': 'True'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'null': 'True', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50', 'null': 'True'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'null': 'True', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'null': 'True', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'null': 'True', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'null': 'True', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'max_length': '30', 'unique': 'True', 'null': 'True'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True'})
        },
        'poem.availabilityexpression': {
            'Meta': {'ordering': "['expr', 'expr_type']", 'object_name': 'AvailabilityExpression', '_ormbases': ['poem.Extension']},
            'expr': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True'}),
            'expr_type': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True'}),
            'extension_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['poem.Extension']", 'unique': 'True', 'primary_key': 'True'})
        },
        'poem.extension': {
            'Meta': {'ordering': "['name']", 'object_name': 'Extension'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'})
        },
        'poem.groupreference': {
            'Meta': {'ordering': "['atp_grouptype', 'atp_groupname']", 'unique_together': "(('atp_grouptype', 'atp_groupname'),)", 'object_name': 'GroupReference'},
            'atp_groupname': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'atp_grouptype': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_deleted': ('django.db.models.fields.CharField', [], {'default': "'N'", 'max_length': '1', 'null': 'True'})
        },
        'poem.metricinstance': {
            'Meta': {'ordering': "['atp_service_type_flavour', 'metric', 'fqan']", 'object_name': 'MetricInstance'},
            'atp_service_type_flavour': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True'}),
            'fqan': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'metric': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True'})
        },
        'poem.profile': {
            'Meta': {'ordering': "['name', 'version']", 'unique_together': "(('name', 'version'),)", 'object_name': 'Profile'},
            'atp_vo': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True'}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '1024', 'null': 'True', 'blank': 'True'}),
            'extensions': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'related_name': "'provider'", 'blank': 'True', 'null': 'True', 'to': "orm['poem.Extension']"}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['poem.GroupReference']", 'symmetrical': 'False', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'metric_instances': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['poem.MetricInstance']", 'null': 'True', 'symmetrical': 'False'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True'}),
            'owner': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'valid': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'valid_from': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'valid_to': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'version': ('django.db.models.fields.CharField', [], {'default': "'1.0'", 'max_length': '10', 'null': 'True'})
        },
        'poem.userprofile': {
            'Meta': {'object_name': 'UserProfile'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'subject': ('django.db.models.fields.CharField', [], {'max_length': '255', 'unique': 'True', 'null': 'True', 'blank': 'True'}),
            'user': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['auth.User']", 'unique': 'True'})
        }
    }

    complete_apps = ['poem']
