try:
    from cStringIO import StringIO
except ImportError:
    from StringIO import StringIO
    
from django.test import TestCase, Client
from django.contrib.auth.models import User
from django.core.handlers.wsgi import WSGIRequest
from django.core.handlers.base import BaseHandler

from Poem.poem.management.validate import ProfileValidation

class RequestFactory(Client):  
    def request(self, **request):  
        """  
        Similar to parent class, but returns the request object as soon as it  
        has created it.  
        """  
        handler = BaseHandler()  
        handler.load_middleware()  
        environ = {  
            'HTTP_COOKIE': self.cookies,  
            'PATH_INFO': '/',  
            'QUERY_STRING': '',  
            'REQUEST_METHOD': 'GET',  
            'SCRIPT_NAME': '',  
            'SERVER_NAME': 'testserver',  
            'SERVER_PORT': 80,  
            'SSL_CLIENT_S_DN_CN': 'tester',
            'SSL_CLIENT_S_DN': '/DC=ch/DC=cern/OU=test/CN=tester',
            'SERVER_PROTOCOL': 'HTTP/1.1',  
            'wsgi.version': (1, 0),
            'wsgi.url_scheme': 'http',
            'wsgi.multiprocess': True,
            'wsgi.multithread':  False,
            'wsgi.run_once':     False,
            'wsgi.input': StringIO("")
        }  
        environ.update(self.defaults)  
        environ.update(request)  
        request = WSGIRequest(environ)  

        for middleware_method in handler._request_middleware:  
            if middleware_method(request):  
                raise Exception("Couldn't create request mock object - "  
                                 "request middleware returned a response")  
        return request

class POEMTest(TestCase):
    fixtures = ['extensions', 'expressions', 'profiles', 'metric_set', 'metricmapping']
    
    def setUp(self):
        self.client = Client()
        self.req_factory = RequestFactory()
        ProfileValidation().run()

    def get_and_find(self, url, text):
        response = self.client.get(url)
        self.failUnlessEqual(response.status_code, 200)
        
        if text:
            self.assertContains(response, text)
            
    def test_api(self):
        self.get_and_find('/api/0.1/json/profiles/', 'ATLAS_critical')
        self.get_and_find('/api/0.1/json/profiles/', 'org.sam.CREAMCE-JobSubmit')
        self.get_and_find('/api/0.1/json/hints/metrics/?term=CE', 'emi.cream.CREAMCE-JobSubmit')
        self.get_and_find('/api/0.1/json/hints/atp_vo/?term=at', 'atlas')
        self.get_and_find('/api/0.1/json/hints/atp_service_type_flavour/?term=CE', 'CE')
        self.get_and_find('/api/0.2/json/profiles/', 'ATLAS_critical')
        self.get_and_find('/api/0.2/json/profiles/', 'emi.cream.CREAMCE-JobSubmit')
        self.get_and_find('/api/0.2/json/hints/metrics/?term=CE', 'emi.cream.CREAMCE-JobSubmit')
        self.get_and_find('/api/0.2/json/hints/atp_vo/?term=at', 'atlas')
        self.get_and_find('/api/0.2/json/hints/atp_service_type_flavour/?term=CE', 'CE')

                
    def test_ssl_authen(self):
        self.assertEqual(self.client.login(request=self.req_factory.request()), True)
        
        self.assertEqual(User.objects.get(username='tester').get_profile().subject, '/DC=ch/DC=cern/OU=test/CN=tester')
        
    def test_profile_list(self):
        self.client.login(request=self.req_factory.request())
        response = self.client.get('/admin/poem/profile/', follow=True, 
                                   **{'SSL_USERNAME': 'tester', 'SSL_DN': '/DC=ch/DC=cern/OU=test/CN=tester'})
        self.assertContains(response, 'ATLAS_critical', count=1, status_code=200)
        
    def test_profile_form(self):
        self.client.login(request=self.req_factory.request())
        response = self.client.get('/admin/poem/profile/1', follow=True,
                                    **{'SSL_USERNAME': 'tester', 'SSL_DN': '/DC=ch/DC=cern/OU=test/CN=tester'})
        self.assertContains(response, 'ATLAS_critical', count=2, status_code=200)
        self.assertContains(response, 'ATLAS', count=5, status_code=200)
        # metric instances
        self.assertContains(response, '/Role=production', count=4, status_code=200)
        self.assertContains(response, 'hr.srce.SRM2-CertLifetime', count=2, status_code=200)
        self.assertContains(response, 'emi.cream.CREAMCE-JobSubmit', count=2, status_code=200)
        
        
#    def test_metricinst_form(self):
#        self.client.login(request=self.req_factory.request())
#        response = self.client.get('/admin/poem/metricinstance/3', follow=True,
#                                    **{'SSL_USERNAME': 'tester', 'SSL_DN': '/DC=ch/DC=cern/OU=test/CN=tester'})
#        
#        self.assertContains(response, '/Role=production', count=2, status_code=200)
#        self.assertContains(response, 'hr.srce.SRM2-CertLifetime', count=2, status_code=200)  
        
#    def test_validation(self):
#        self.client.login(request=self.req_factory.request())
#        response = self.client.get('/admin/poem/profile/', follow=True, 
#                                    **{'SSL_USERNAME': 'tester', 'SSL_DN': '/DC=ch/DC=cern/OU=test/CN=tester'})
#        
#        self.assertContains(response, 'icon-no.gif', count=2, status_code=200)
        
        
      
        
        
