BEGIN;
CREATE TABLE `django_content_type` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(100) NOT NULL,
    `app_label` varchar(100) NOT NULL,
    `model` varchar(100) NOT NULL,
    UNIQUE (`app_label`, `model`)
)
;
CREATE TABLE `django_session` (
    `session_key` varchar(40) NOT NULL PRIMARY KEY,
    `session_data` longtext NOT NULL,
    `expire_date` datetime NOT NULL
)
;
CREATE INDEX `django_session_c25c2c28` ON `django_session` (`expire_date`);
CREATE TABLE `auth_permission` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(50) NOT NULL,
    `content_type_id` integer NOT NULL,
    `codename` varchar(100) NOT NULL,
    UNIQUE (`content_type_id`, `codename`)
)
;
ALTER TABLE `auth_permission` ADD CONSTRAINT `content_type_id_refs_id_728de91f` FOREIGN KEY (`content_type_id`) REFERENCES `django_content_type` (`id`);
CREATE TABLE `auth_group_permissions` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `group_id` integer NOT NULL,
    `permission_id` integer NOT NULL,
    UNIQUE (`group_id`, `permission_id`)
)
;
ALTER TABLE `auth_group_permissions` ADD CONSTRAINT `permission_id_refs_id_a7792de1` FOREIGN KEY (`permission_id`) REFERENCES `auth_permission` (`id`);
CREATE TABLE `auth_group` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(80) NOT NULL UNIQUE
)
;
ALTER TABLE `auth_group_permissions` ADD CONSTRAINT `group_id_refs_id_3cea63fe` FOREIGN KEY (`group_id`) REFERENCES `auth_group` (`id`);
CREATE TABLE `auth_user_user_permissions` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `user_id` integer NOT NULL,
    `permission_id` integer NOT NULL,
    UNIQUE (`user_id`, `permission_id`)
)
;
ALTER TABLE `auth_user_user_permissions` ADD CONSTRAINT `permission_id_refs_id_67e79cb` FOREIGN KEY (`permission_id`) REFERENCES `auth_permission` (`id`);
CREATE TABLE `auth_user_groups` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `user_id` integer NOT NULL,
    `group_id` integer NOT NULL,
    UNIQUE (`user_id`, `group_id`)
)
;
ALTER TABLE `auth_user_groups` ADD CONSTRAINT `group_id_refs_id_f0ee9890` FOREIGN KEY (`group_id`) REFERENCES `auth_group` (`id`);
CREATE TABLE `auth_user` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `username` varchar(30) NOT NULL UNIQUE,
    `first_name` varchar(30) NOT NULL,
    `last_name` varchar(30) NOT NULL,
    `email` varchar(75) NOT NULL,
    `password` varchar(128) NOT NULL,
    `is_staff` bool NOT NULL,
    `is_active` bool NOT NULL,
    `is_superuser` bool NOT NULL,
    `last_login` datetime NOT NULL,
    `date_joined` datetime NOT NULL
)
;
ALTER TABLE `auth_user_user_permissions` ADD CONSTRAINT `user_id_refs_id_f2045483` FOREIGN KEY (`user_id`) REFERENCES `auth_user` (`id`);
ALTER TABLE `auth_user_groups` ADD CONSTRAINT `user_id_refs_id_831107f1` FOREIGN KEY (`user_id`) REFERENCES `auth_user` (`id`);
CREATE TABLE `auth_message` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `user_id` integer NOT NULL,
    `message` longtext NOT NULL
)
;
ALTER TABLE `auth_message` ADD CONSTRAINT `user_id_refs_id_9af0b65a` FOREIGN KEY (`user_id`) REFERENCES `auth_user` (`id`);
CREATE INDEX `auth_permission_e4470c6e` ON `auth_permission` (`content_type_id`);
CREATE INDEX `auth_message_fbfc09f1` ON `auth_message` (`user_id`);
CREATE TABLE `django_admin_log` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `action_time` datetime NOT NULL,
    `user_id` integer NOT NULL,
    `content_type_id` integer,
    `object_id` longtext,
    `object_repr` varchar(200) NOT NULL,
    `action_flag` smallint UNSIGNED NOT NULL,
    `change_message` longtext NOT NULL
)
;
ALTER TABLE `django_admin_log` ADD CONSTRAINT `user_id_refs_id_c8665aa` FOREIGN KEY (`user_id`) REFERENCES `auth_user` (`id`);
ALTER TABLE `django_admin_log` ADD CONSTRAINT `content_type_id_refs_id_288599e6` FOREIGN KEY (`content_type_id`) REFERENCES `django_content_type` (`id`);
CREATE INDEX `django_admin_log_fbfc09f1` ON `django_admin_log` (`user_id`);
CREATE INDEX `django_admin_log_e4470c6e` ON `django_admin_log` (`content_type_id`);
CREATE TABLE `taggit_tag` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(100) NOT NULL,
    `slug` varchar(100) NOT NULL UNIQUE
)
;
CREATE TABLE `taggit_taggeditem` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `tag_id` integer NOT NULL,
    `object_id` integer NOT NULL,
    `content_type_id` integer NOT NULL
)
;
ALTER TABLE `taggit_taggeditem` ADD CONSTRAINT `tag_id_refs_id_c87e3f85` FOREIGN KEY (`tag_id`) REFERENCES `taggit_tag` (`id`);
ALTER TABLE `taggit_taggeditem` ADD CONSTRAINT `content_type_id_refs_id_5a2b7711` FOREIGN KEY (`content_type_id`) REFERENCES `django_content_type` (`id`);
CREATE INDEX `taggit_taggeditem_3747b463` ON `taggit_taggeditem` (`tag_id`);
CREATE INDEX `taggit_taggeditem_829e37fd` ON `taggit_taggeditem` (`object_id`);
CREATE INDEX `taggit_taggeditem_e4470c6e` ON `taggit_taggeditem` (`content_type_id`);
CREATE TABLE `poem_userprofile` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `user_id` integer NOT NULL UNIQUE,
    `subject` varchar(255) UNIQUE
)
;
ALTER TABLE `poem_userprofile` ADD CONSTRAINT `user_id_refs_id_cd0798e4` FOREIGN KEY (`user_id`) REFERENCES `auth_user` (`id`);
CREATE TABLE `poem_extension` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(100)
)
;
CREATE TABLE `poem_availabilityexpression` (
    `extension_ptr_id` integer NOT NULL PRIMARY KEY,
    `expr` varchar(255) NOT NULL,
    `expr_type` varchar(255) NOT NULL
)
;
ALTER TABLE `poem_availabilityexpression` ADD CONSTRAINT `extension_ptr_id_refs_id_e865d23c` FOREIGN KEY (`extension_ptr_id`) REFERENCES `poem_extension` (`id`);
CREATE TABLE `poem_profile_extensions` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `profile_id` integer NOT NULL,
    `extension_id` integer NOT NULL,
    UNIQUE (`profile_id`, `extension_id`)
)
;
ALTER TABLE `poem_profile_extensions` ADD CONSTRAINT `extension_id_refs_id_ee04b375` FOREIGN KEY (`extension_id`) REFERENCES `poem_extension` (`id`);
CREATE TABLE `poem_profile` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(128) NOT NULL,
    `version` varchar(10) NOT NULL,
    `valid` bool NOT NULL,
    `atp_vo` varchar(128) NOT NULL,
    `valid_from` datetime,
    `valid_to` datetime,
    `owner` varchar(255),
    `description` varchar(1024),
    UNIQUE (`name`, `version`)
)
;
ALTER TABLE `poem_profile_extensions` ADD CONSTRAINT `profile_id_refs_id_7b2386d` FOREIGN KEY (`profile_id`) REFERENCES `poem_profile` (`id`);
CREATE TABLE `poem_metricinstance` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `profile_id` integer NOT NULL,
    `atp_service_type_flavour` varchar(128) NOT NULL,
    `metric` varchar(128) NOT NULL,
    `vo` varchar(128),
    `fqan` varchar(128),
    UNIQUE (`profile_id`, `atp_service_type_flavour`, `metric`, `fqan`)
)
;
ALTER TABLE `poem_metricinstance` ADD CONSTRAINT `profile_id_refs_id_82279608` FOREIGN KEY (`profile_id`) REFERENCES `poem_profile` (`id`);
CREATE TABLE `poem_groupreference` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `profile_id` integer NOT NULL,
    `atp_grouptype` varchar(100),
    `atp_groupname` varchar(100),
    `is_deleted` varchar(1) NOT NULL,
    `description` varchar(255),
    UNIQUE (`profile_id`, `atp_grouptype`, `atp_groupname`)
)
;
ALTER TABLE `poem_groupreference` ADD CONSTRAINT `profile_id_refs_id_48941cfb` FOREIGN KEY (`profile_id`) REFERENCES `poem_profile` (`id`);
INSERT INTO schema_details(ver,creation_date,remarks,db_name) VALUES('1.4',NOW(),"Version 1.4 of the schema","poem");
CREATE INDEX `poem_metricinstance_141c6eec` ON `poem_metricinstance` (`profile_id`);
CREATE INDEX `poem_groupreference_141c6eec` ON `poem_groupreference` (`profile_id`);
COMMIT;
