CREATE TABLE "DJANGO_CONTENT_TYPE" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "NAME" NVARCHAR2(100),
    "APP_LABEL" NVARCHAR2(100),
    "MODEL" NVARCHAR2(100),
    UNIQUE ("APP_LABEL", "MODEL")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'DJANGO_CONTENT_TYPE_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "DJANGO_CONTENT_TYPE_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "DJANGO_CONTENT_TYPE_TR"
BEFORE INSERT ON "DJANGO_CONTENT_TYPE"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "DJANGO_CONTENT_TYPE_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "AUTH_PERMISSION" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "NAME" NVARCHAR2(50),
    "CONTENT_TYPE_ID" NUMBER(11) NOT NULL REFERENCES "DJANGO_CONTENT_TYPE" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "CODENAME" NVARCHAR2(100),
    UNIQUE ("CONTENT_TYPE_ID", "CODENAME")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'AUTH_PERMISSION_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "AUTH_PERMISSION_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "AUTH_PERMISSION_TR"
BEFORE INSERT ON "AUTH_PERMISSION"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "AUTH_PERMISSION_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "AUTH_GROUP" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "NAME" NVARCHAR2(80) UNIQUE
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'AUTH_GROUP_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "AUTH_GROUP_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "AUTH_GROUP_TR"
BEFORE INSERT ON "AUTH_GROUP"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "AUTH_GROUP_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "AUTH_USER" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "USERNAME" NVARCHAR2(30) UNIQUE,
    "FIRST_NAME" NVARCHAR2(30),
    "LAST_NAME" NVARCHAR2(30),
    "EMAIL" NVARCHAR2(75),
    "PASSWORD" NVARCHAR2(128),
    "IS_STAFF" NUMBER(1) CHECK ("IS_STAFF" IN (0,1)) NOT NULL,
    "IS_ACTIVE" NUMBER(1) CHECK ("IS_ACTIVE" IN (0,1)) NOT NULL,
    "IS_SUPERUSER" NUMBER(1) CHECK ("IS_SUPERUSER" IN (0,1)) NOT NULL,
    "LAST_LOGIN" TIMESTAMP NOT NULL,
    "DATE_JOINED" TIMESTAMP NOT NULL
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'AUTH_USER_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "AUTH_USER_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "AUTH_USER_TR"
BEFORE INSERT ON "AUTH_USER"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "AUTH_USER_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "AUTH_MESSAGE" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "USER_ID" NUMBER(11) NOT NULL REFERENCES "AUTH_USER" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "MESSAGE" NCLOB
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'AUTH_MESSAGE_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "AUTH_MESSAGE_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "AUTH_MESSAGE_TR"
BEFORE INSERT ON "AUTH_MESSAGE"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "AUTH_MESSAGE_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "AUTH_GROUP_PERMISSIONS" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "GROUP_ID" NUMBER(11) NOT NULL REFERENCES "AUTH_GROUP" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "PERMISSION_ID" NUMBER(11) NOT NULL REFERENCES "AUTH_PERMISSION" ("ID") DEFERRABLE INITIALLY DEFERRED,
    UNIQUE ("GROUP_ID", "PERMISSION_ID")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'AUTH_GROUP_PERMISSIONS_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "AUTH_GROUP_PERMISSIONS_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "AUTH_GROUP_PERMISSIONS_TR"
BEFORE INSERT ON "AUTH_GROUP_PERMISSIONS"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "AUTH_GROUP_PERMISSIONS_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "AUTH_USER_GROUPS" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "USER_ID" NUMBER(11) NOT NULL REFERENCES "AUTH_USER" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "GROUP_ID" NUMBER(11) NOT NULL REFERENCES "AUTH_GROUP" ("ID") DEFERRABLE INITIALLY DEFERRED,
    UNIQUE ("USER_ID", "GROUP_ID")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'AUTH_USER_GROUPS_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "AUTH_USER_GROUPS_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "AUTH_USER_GROUPS_TR"
BEFORE INSERT ON "AUTH_USER_GROUPS"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "AUTH_USER_GROUPS_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "AUTH_USER_USER_PERMISSIONS" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "USER_ID" NUMBER(11) NOT NULL REFERENCES "AUTH_USER" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "PERMISSION_ID" NUMBER(11) NOT NULL REFERENCES "AUTH_PERMISSION" ("ID") DEFERRABLE INITIALLY DEFERRED,
    UNIQUE ("USER_ID", "PERMISSION_ID")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'AUTH_USER_USER_PERMISSIONS_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "AUTH_USER_USER_PERMISSIONS_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "AUTH_USER_USER_PERMISSIONS_TR"
BEFORE INSERT ON "AUTH_USER_USER_PERMISSIONS"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "AUTH_USER_USER_PERMISSIONS_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE INDEX "AUTH_PERMISSION_CONTENT_TY2BCE" ON "AUTH_PERMISSION" ("CONTENT_TYPE_ID");
CREATE INDEX "AUTH_MESSAGE_USER_ID" ON "AUTH_MESSAGE" ("USER_ID");
CREATE TABLE "DJANGO_SESSION" (
    "SESSION_KEY" NVARCHAR2(40) PRIMARY KEY,
    "SESSION_DATA" NCLOB,
    "EXPIRE_DATE" TIMESTAMP NOT NULL
)
;
CREATE TABLE "DJANGO_ADMIN_LOG" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "ACTION_TIME" TIMESTAMP NOT NULL,
    "USER_ID" NUMBER(11) NOT NULL REFERENCES "AUTH_USER" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "CONTENT_TYPE_ID" NUMBER(11) REFERENCES "DJANGO_CONTENT_TYPE" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "OBJECT_ID" NCLOB,
    "OBJECT_REPR" NVARCHAR2(200),
    "ACTION_FLAG" NUMBER(11) CHECK ("ACTION_FLAG" >= 0) NOT NULL,
    "CHANGE_MESSAGE" NCLOB
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'DJANGO_ADMIN_LOG_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "DJANGO_ADMIN_LOG_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "DJANGO_ADMIN_LOG_TR"
BEFORE INSERT ON "DJANGO_ADMIN_LOG"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "DJANGO_ADMIN_LOG_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE INDEX "DJANGO_ADMIN_LOG_USER_ID" ON "DJANGO_ADMIN_LOG" ("USER_ID");
CREATE INDEX "DJANGO_ADMIN_LOG_CONTENT_T6E98" ON "DJANGO_ADMIN_LOG" ("CONTENT_TYPE_ID");
CREATE TABLE "POEM_USERPROFILE" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "USER_ID" NUMBER(11) NOT NULL UNIQUE REFERENCES "AUTH_USER" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "SUBJECT" NVARCHAR2(255) UNIQUE
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_USERPROFILE_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_USERPROFILE_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_USERPROFILE_TR"
BEFORE INSERT ON "POEM_USERPROFILE"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_USERPROFILE_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_EXTENSION" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "NAME" NVARCHAR2(100)
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_EXTENSION_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_EXTENSION_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_EXTENSION_TR"
BEFORE INSERT ON "POEM_EXTENSION"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_EXTENSION_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_AVAILABILITYEXPRESSION" (
    "EXTENSION_PTR_ID" NUMBER(11) NOT NULL PRIMARY KEY REFERENCES "POEM_EXTENSION" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "EXPR" NVARCHAR2(255),
    "EXPR_TYPE" NVARCHAR2(255)
)
;
CREATE TABLE "POEM_PROFILE" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "NAME" NVARCHAR2(128),
    "VERSION" NVARCHAR2(10),
    "VALID" NUMBER(1) CHECK ("VALID" IN (0,1)) NOT NULL,
    "ATP_VO" NVARCHAR2(128),
    "VALID_FROM" TIMESTAMP,
    "VALID_TO" TIMESTAMP,
    "OWNER" NVARCHAR2(255),
    "DESCRIPTION" NVARCHAR2(1024),
    UNIQUE ("NAME", "VERSION")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_PROFILE_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_PROFILE_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_PROFILE_TR"
BEFORE INSERT ON "POEM_PROFILE"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_PROFILE_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_METRICINSTANCE" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "PROFILE_ID" NUMBER(11) NOT NULL REFERENCES "POEM_PROFILE" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "ATP_SERVICE_TYPE_FLAVOUR" NVARCHAR2(128),
    "METRIC" NVARCHAR2(128),
    "VO" NVARCHAR2(128),
    "FQAN" NVARCHAR2(128),
    UNIQUE ("PROFILE_ID", "ATP_SERVICE_TYPE_FLAVOUR", "METRIC", "VO", "FQAN")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_METRICINSTANCE_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_METRICINSTANCE_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_METRICINSTANCE_TR"
BEFORE INSERT ON "POEM_METRICINSTANCE"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_METRICINSTANCE_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_GROUPREFERENCE" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "PROFILE_ID" NUMBER(11) NOT NULL REFERENCES "POEM_PROFILE" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "ATP_GROUPTYPE" NVARCHAR2(100),
    "ATP_GROUPNAME" NVARCHAR2(100),
    "IS_DELETED" NVARCHAR2(1),
    "DESCRIPTION" NVARCHAR2(255),
    UNIQUE ("PROFILE_ID", "ATP_GROUPTYPE", "ATP_GROUPNAME")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_GROUPREFERENCE_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_GROUPREFERENCE_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_GROUPREFERENCE_TR"
BEFORE INSERT ON "POEM_GROUPREFERENCE"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_GROUPREFERENCE_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_PROFILE_EXTENSIONS" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "PROFILE_ID" NUMBER(11) NOT NULL REFERENCES "POEM_PROFILE" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "EXTENSION_ID" NUMBER(11) NOT NULL REFERENCES "POEM_EXTENSION" ("ID") DEFERRABLE INITIALLY DEFERRED,
    UNIQUE ("PROFILE_ID", "EXTENSION_ID")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_PROFILE_EXTENSIONS_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_PROFILE_EXTENSIONS_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_PROFILE_EXTENSIONS_TR"
BEFORE INSERT ON "POEM_PROFILE_EXTENSIONS"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_PROFILE_EXTENSIONS_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
INSERT INTO schema_details(ver,creation_date,remarks,db_name) VALUES('1.3', sysdate, 'Version 1.3 of the schema', 'poem');
CREATE INDEX "POEM_METRICINSTANCE_PROFILE_ID" ON "POEM_METRICINSTANCE" ("PROFILE_ID");
CREATE INDEX "POEM_GROUPREFERENCE_PROFILE_ID" ON "POEM_GROUPREFERENCE" ("PROFILE_ID");
COMMIT;
